@@ -192,12 +192,12 @@ champlain_cache_class_init (ChamplainCacheClass *klass)
   g_object_class_install_property (object_class,
       PROP_SIZE_LIMIT,
       g_param_spec_uint ("size-limit",
-        "Size Limit",
-        "The cache's size limit (Mb)",
-        1,
-        G_MAXINT,
-        100000000,
-        G_PARAM_READWRITE));
+          "Size Limit",
+          "The cache's size limit (Mb)",
+          1,
+          G_MAXINT,
+          100000000,
+          G_PARAM_READWRITE));
 }
 
 static void
@@ -237,16 +237,28 @@ champlain_cache_init (ChamplainCache *self)
       goto cleanup;
     }
 
+  sqlite3_exec (priv->data,
+      "PRAGMA synchronous=OFF;"
+      "PRAGMA count_changes=OFF;",
+      NULL, NULL, &error_msg);
+  if (error_msg != NULL)
+    {
+      DEBUG ("Set PRAGMA: %s", error_msg);
+      sqlite3_free (error_msg);
+      goto cleanup;
+    }
+
   sqlite3_exec (priv->data,
       "CREATE TABLE IF NOT EXISTS tiles ("
-      "filename TEXT PRIMARY KEY, etag TEXT, "
+      "filename TEXT PRIMARY KEY, "
+      "etag TEXT, "
       "popularity INT DEFAULT 1, "
       "size INT DEFAULT 0)",
       NULL, NULL, &error_msg);
   if (error_msg != NULL)
     {
       DEBUG ("Creating table 'tiles' failed: %s", error_msg);
-          sqlite3_free (error_msg);
+      sqlite3_free (error_msg);
       goto cleanup;
     }
 
@@ -280,7 +292,7 @@ cleanup:
 /**
  * champlain_cache_dup_default:
  *
- * Returns the #ChamplainCache singleton, use #g_object_unref when not neeeded
+ * Returns: the #ChamplainCache singleton, use #g_object_unref when not neeeded
  * anymore.
  *
  *
@@ -292,17 +304,11 @@ champlain_cache_dup_default (void)
   return g_object_new (CHAMPLAIN_TYPE_CACHE, NULL);
 }
 
-ChamplainCache*
-champlain_cache_get_default (void)
-{
-  return champlain_cache_dup_default ();
-}
-
 /**
  * champlain_cache_get_size_limit:
  * @self: the #ChamplainCache
  *
- * Returns the cache size limit in bytes
+ * Returns: the cache size limit in bytes
  *
  * Since: 0.4
  */
@@ -344,7 +350,7 @@ champlain_cache_set_size_limit (ChamplainCache *self,
  *
  * Loads data from disk for the given tile
  *
- * Returns TRUE if the tile was in cache, false if it needs to be
+ * Returns: TRUE if the tile was in cache, false if it needs to be
  * loaded from network
  *
  * Since: 0.4
@@ -368,6 +374,7 @@ champlain_cache_fill_tile (ChamplainCache *self,
   ChamplainCachePrivate *priv = GET_PRIVATE (self);
 
   filename = champlain_tile_get_filename (tile);
+  DEBUG ("fill of %s", filename);
 
   if (!g_file_test (filename, G_FILE_TEST_EXISTS))
     goto cleanup;
@@ -447,8 +454,7 @@ cleanup:
  * @self: the #ChamplainCache
  * @tile: the #ChamplainTile to fill
  *
- * Returns TRUE if the tile should be
- * reloaded from network
+ * Returns: TRUE if the tile should be reloaded from network, FALSE otherwize.
  *
  * Since: 0.4
  */
@@ -467,6 +473,8 @@ champlain_cache_tile_is_expired (ChamplainCache *self,
   g_time_val_add (&now, (-24ul * 60ul * 60ul * 1000ul * 1000ul * 7ul)); // Cache expires 7 days
   validate_cache = modified_time->tv_sec < now.tv_sec;
 
+  DEBUG ("%p is %s expired", tile, (validate_cache ? "": "not"));
+
   return validate_cache;
 }
 
@@ -488,6 +496,8 @@ inc_popularity (gpointer data)
   last = g_slist_last (priv->popularity_queue);
   filename = last->data;
 
+  DEBUG ("popularity of %s", filename);
+
   sql_rc = sqlite3_bind_text (priv->stmt_update, 1, filename, -1, SQLITE_STATIC);
   if (sql_rc != SQLITE_OK)
     {
@@ -511,7 +521,7 @@ cleanup:
   g_free (filename);
 
   /* Ask to be called again until the list is emptied */
-  return TRUE;
+  return priv->popularity_queue != NULL;
 }
 
 static void
@@ -567,6 +577,8 @@ champlain_cache_update_tile (ChamplainCache *self,
 
   ChamplainCachePrivate *priv = GET_PRIVATE (self);
 
+  DEBUG ("Update of %p", tile);
+
   query = sqlite3_mprintf ("REPLACE INTO tiles (filename, etag, size) VALUES (%Q, %Q, %d)",
       champlain_tile_get_filename (tile),
       champlain_tile_get_etag (tile),
